Module: MatchReduce
- Defined in:
- lib/match_reduce.rb,
lib/match_reduce/index.rb,
lib/match_reduce/version.rb,
lib/match_reduce/processor.rb,
lib/match_reduce/aggregator.rb,
lib/match_reduce/processor/result.rb,
lib/match_reduce/processor/result_builder.rb,
lib/match_reduce/processor/results_builder.rb
Overview
Copyright © 2019-present, Blue Marble Payroll, LLC
This source code is licensed under the MIT license found in the LICENSE file in the root directory of this source tree.
Defined Under Namespace
Classes: Aggregator, Index, Processor
Constant Summary collapse
- ANY =
Something unique which will represent “match on all values”. This is used as the base value for all pattern keys.
:__ANY__- VERSION =
'1.0.0'